from setuptools import setup

setup(
    name="pythonspinners",
    version="0.1.0a",
    author="Abhiram Mangipudi",
    author_email="k0mplexontuta@tutamail.com",
    description="A simple package that provided loading screen objects for a passed function.",
    packages=["pythonspinners"],
)
